(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
	typeof define === 'function' && define.amd ? define(factory) :
	(global['sip-css'] = factory());
}(this, (function () { 'use strict';

/**
  * @constant properties
  * @type {Object}
  * @desc Lexicon of shorthand CSS properties
  * @default
*/
var properties = {
  ai: 'align-items',
  b: 'bottom',
  bg: 'background',
  bw: 'border-width',
  bs: 'border-style',
  c: 'cursor',
  d: 'display',
  fd: 'flex-direction',
  fs: 'font-size',
  fw: 'font-weight',
  h: 'height',
  l: 'left',
  lh: 'line-height',
  m: 'margin',
  mt: 'margin-top',
  mr: 'margin-right',
  mb: 'margin-bottom',
  ml: 'margin-left',
  o: 'overflow',
  p: 'padding',
  pb: 'padding-bottom',
  pe: 'pointer-events',
  pl: 'padding-left',
  po: 'position',
  pr: 'padding-right',
  pt: 'padding-top',
  r: 'right',
  t: 'top',
  ta: 'text-align',
  td: 'text-decoration',
  to: 'text-overflow',
  tt: 'text-transform',
  va: 'vertical-align',
  w: 'width',
  ws: 'white-space',
  z: 'z-index',
};

/**
  * @constant values
  * @type {Object}
  * @desc Map of shorthand static CSS values keyed by corresponding CSS property
  * @default
*/
var values = {
  ai: {
    c: 'center',
    e: 'flex-end',
    s: 'flex-start',
  },
  bg: {
    t: 'transparent',
  },
  bs: {
    da: 'dashed',
    do: 'dotted',
    s: 'solid',
  },
  c: {
    a: 'auto',
    c: 'copy',
    d: 'default',
    p: 'pointer',
    w: 'wait',
  },
  d: {
    b: 'block',
    i: 'inline',
    ib: 'inline-block',
    n: 'none',
    f: 'flex',
    t: 'table',
    tc: 'table-cell',
    tr: 'table-row',
  },
  fd: {
    c: 'column',
    r: 'row',
  },
  fw: {
    n: 400,
    b: 700,
  },
  o: {
    a: 'auto',
    h: 'hidden',
    s: 'scroll',
    v: 'visible',
  },
  pe: {
    n: 'none',
    i: 'initial',
  },
  po: {
    s: 'static',
    r: 'relative',
    a: 'absolute',
    f: 'fixed',
  },
  ta: {
    c: 'center',
    l: 'left',
    r: 'right',
    j: 'justify',
  },
  td: {
    u: 'underline',
    o: 'overline',
    n: 'none',
  },
  to: {
    c: 'clip',
    e: 'ellipsis',
  },
  tt: {
    u: 'uppercase',
  },
  va: {
    l: 'baseline',
    tt: 'text-top',
    tb: 'text-bottom',
    m: 'middle',
    t: 'top',
    b: 'bottom',
  },
  ws: {
    n: 'nowrap',
    p: 'pre',
    pw: 'pre-wrap',
    pl: 'pre-line',
  },
};

/**
  * @constant SCALE
  * @type {Array}
  * @desc Modular CSS Scale
  * @see http://jxnblk.com/modular/
  * @example [ 0, 8, 9 ... ]
*/
var SCALE = [
  0,
  8,
  9,
  12,
  16,
  18,
  24,
  32,
  36,
  48,
  64,
  72,
  96,
  128,
  144,
  256 ];

/**
  * @constant UNIT
  * @type {String}
  * @desc Default CSS length unit
  * @see https://developer.mozilla.org/en/docs/Web/CSS/length
  * @example 'px'
  * @default
*/
var UNIT = 'px';

/**
  * @function getScaledValue
  * @desc Decorator for `createScaledValueGetter` that sets the default `scale` and `unit` to use
  * @param {Number} scaleIndex - index on scale
  * @param {String} [unit=UNIT] - CSS length unit
  * @returns {Number} Returns the result of `createScaledValueGetter`
*/

/**
  * @function createScaledPropertyGetter
  * @desc Resolve method for scaled properties
  * @param {String} property - CSS property
  * @param {Number} value - scale index
  * @param {String} unit - CSS length unit
  * @param {Array} [scale=SCALE] - modular scale
  * @returns {Object} Returns a scaled CSS attribute
*/
var createScaledPropertyGetter = function (property, value, unit, scale) {
    if ( scale === void 0 ) scale = SCALE;

    return typeof value === 'number' &&
    typeof scale[value] === 'number' &&
    typeof properties[property] === 'string'
    ? ( obj = {}, obj[("" + (properties[property]))] = ("" + (scale[value]) + unit), obj )
    : null
    var obj;
};

/**
  * @function createComputedPropertyGetter
  * @desc Resolve method for scaled properties
  * @param {String} property - CSS property
  * @param {Number} value - CSS length value
  * @param {String} unit - CSS length unit
  * @returns {Object} Returns a computed CSS attribute
*/
var createComputedPropertyGetter = function (property, value, unit) { return typeof value === 'number' && typeof properties[property] === 'string'
    ? ( obj = {}, obj[("" + (properties[property]))] = ("" + value + unit), obj )
    : null
    var obj; };

/**
  * @function createStaticPropertyGetter
  * @desc Resolve method for scaled properties
  * @param {String} property - CSS property
  * @param {Number} value - CSS value
  * @returns {Object} Returns a static CSS attribute
*/
var createStaticPropertyGetter = function (property, value) { return typeof properties[property] === 'string' &&
    typeof values[property] === 'object' &&
    typeof values[property][value] !== 'undefined'
    ? ( obj = {}, obj[("" + (properties[property]))] = ("" + (values[property][value])), obj )
    : null
    var obj; };

/**
  * @function createActualPropertyGetter
  * @desc Resolve method for scaled properties
  * @param {String} property - CSS property
  * @param {Number} value - CSS value
  * @returns {Object} Returns an actual CSS attribute
*/
var createActualPropertyGetter = function (property, value) { return typeof properties[property] === 'string'
    ? ( obj = {}, obj[("" + (properties[property]))] = value, obj )
    : null
    var obj; };

/**
  * @function getScaledProperty
  * @desc Resolve method creator for scaled properties
  * @param {String} property - CSS property
  * @param {Number} value - scale index
  * @param {String} [unit=UNIT] - CSS length unit
  * @returns {Object} Returns the result of `createScaledPropertyGetter`
*/
var getScaledProperty = function (property, value, unit) {
    if ( unit === void 0 ) unit = UNIT;

    return createScaledPropertyGetter(property, value, unit);
};

/**
  * @function getComputedProperty
  * @desc Resolve method creator for computer properties
  * @param {String} property - CSS property
  * @param {Number} value - CSS length value
  * @param {String} [unit=UNIT] - CSS length unit
  * @returns {Object} Returns the result of `createComputedPropertyGetter`
*/
var getComputedProperty = function (property, value, unit) {
    if ( unit === void 0 ) unit = UNIT;

    return createComputedPropertyGetter(property, value, unit);
};

/**
  * @function getStaticProperty
  * @desc Resolve method creator for static properties
  * @param {String} property - CSS property
  * @param {String} value - CSS value
  * @returns {Object} Returns the result of `createStaticPropertyGetter`
*/
var getStaticProperty = function (property, value) { return createStaticPropertyGetter(property, value); };

/**
  * @function getActualProperty
  * @desc Resolve method creator for actual properties
  * @param {String} property - CSS property
  * @param {String} value - CSS value
  * @returns {Object} Returns the result of `createActualPropertyGetter`
*/
var getActualProperty = function (property, value) { return createActualPropertyGetter(property, value); };

/**
  * @constant getters
  * @type {Object}
  * @desc CSS attribute getters for shorthand properties
*/
var getters = {
  ai: function (value) { return getStaticProperty('ai', value); },
  b: function (value) { return getScaledProperty('b', value); },
  bg: function (value) { return getStaticProperty('bg', value); },
  bs: function (value) { return getStaticProperty('bs', value); },
  bw: function (value) { return getComputedProperty('bw', value); },
  c: function (value) { return getStaticProperty('c', value); },
  d: function (value) { return getStaticProperty('d', value); },
  fd: function (value) { return getStaticProperty('fd', value); },
  fs: function (value) { return getScaledProperty('fs', value); },
  fw: function (value) { return getStaticProperty('fw', value); },
  h: function (value) { return getScaledProperty('h', value); },
  l: function (value) { return getScaledProperty('l', value); },
  lh: function (value) { return getScaledProperty('lh', value); },
  m: function (value) { return getScaledProperty('m', value); },
  mt: function (value) { return getScaledProperty('mt', value); },
  mr: function (value) { return getScaledProperty('mr', value); },
  mb: function (value) { return getScaledProperty('mb', value); },
  ml: function (value) { return getScaledProperty('ml', value); },
  o: function (value) { return getStaticProperty('o', value); },
  p: function (value) { return getScaledProperty('p', value); },
  pt: function (value) { return getScaledProperty('pt', value); },
  pr: function (value) { return getScaledProperty('pr', value); },
  pb: function (value) { return getScaledProperty('pb', value); },
  pl: function (value) { return getScaledProperty('pl', value); },
  pe: function (value) { return getStaticProperty('pe', value); },
  po: function (value) { return getStaticProperty('po', value); },
  r: function (value) { return getScaledProperty('r', value); },
  t: function (value) { return getScaledProperty('t', value); },
  ta: function (value) { return getStaticProperty('ta', value); },
  td: function (value) { return getStaticProperty('td', value); },
  to: function (value) { return getStaticProperty('to', value); },
  tt: function (value) { return getStaticProperty('tt', value); },
  va: function (value) { return getStaticProperty('va', value); },
  w: function (value) { return getScaledProperty('w', value); },
  ws: function (value) { return getStaticProperty('ws', value); },
  z: function (value) { return getActualProperty('z', value); },
};

var Sip = function (sip) {
  if (typeof sip !== 'object') { return; }

  var sips = {};

  for (var prop in sip) {
    if (sip.hasOwnProperty(prop) && getters[prop]) {
      sips = Object.assign({}, sips, getters[prop](sip[prop]));
    }
  }

  return sips;
};

return Sip;

})));
//# sourceMappingURL=sip.js.map
